==> gsnodegraph-0.5.0.tar.gz: gsnodegraph-0.5.0/README.md <==
#   g s n o d e g r a p h 
 
 
 
 P o w e r f u l   c u s t o m   n o d e   g r a p h   w i d g e t   f o r   w x P y t h o n ,   c r e a t e d   t o   b e   u s e d   i n   [ G i m e l   S t u d i o ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o ) . 
 
 
 
 H i g h l y   i n s p i r e d   b y   t h e   o v e r a l l   l o o k   o f   t h e   n o d e s   i n   B l e n d e r   3 D ,   i f   y o u   c o u l d n ' t   t e l l .   S o   i f   y o u ' v e   a l w a y s   w a n t e d   t o   f i n d   a   n o d e   e d i t o r   s i m i l a r   t o   B l e n d e r ' s ,   t h i s   i s   l i k e l y   y o u r   r e p o .   ; ) 
 
 
 
 I t   i s   s p e c i f i c a l l y   a i m e d   t o w a r d s   a n   i m a g e - e d i t i n g   n o d e   e d i t o r   s e t u p   a n d   i s   s e t u p   w i t h   s t y l i n g   s p e c i f i c   t o   G i m e l   S t u d i o   b y   d e f a u l t .   H o w e v e r ,   m a n y   c o l o r s   a n d   s e t t i n g s   c a n   b e   c h a n g e d   v i a   t h e   ` ` c o n s t a n t s . p y ` `   f i l e   a n d / o r   i t   c a n   b e   a d a p t e d   a n d   c h a n g e d   f o r   o t h e r   n o d e   g r a p h   u s e - c a s e s   w i t h   a   l i t t l e   k n o w l e g e   o f   w x P y t h o n . 
 
 
 
 
 
 # #   U s a g e 
 
 
 
 S i m p l y   ` ` ` p i p   i n s t a l l   g s n o d e g r a p h ` ` `   a n d   r u n   t h e   ` ` ` m a i n . p y ` ` `   f o u n d   i n   t h i s   r e p o   t o   s e e   t h e   n o d e   g r a p h   d e m o .   T h e   ` ` n o d e g r a p h . p y ` `   f i l e   s h o w s   h o w   y o u   c a n   c u s t o m i z e   a n d   o v e r r i d e   t h e   n o d e   g r a p h .   T h e   ` ` n o d e s . p y ` `   f i l e   i n   t h e   ` ` n o d e s ` `   f o l d e r   g i v e s   a   d e m o   o f   h o w   t o   s e t u p   n o d e s   t o   w o r k   w i t h   t h e   n o d e   g r a p h . 
 
 
 
 F o r   a   r e a l - l i f e   e x a m p l e   o f   t h i s   n o d e   g r a p h   i n   a c t i o n ,   s e e   [ G i m e l   S t u d i o ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o )   a   n o d e - b a s e d   2 D   i m a g e   e d i t o r   f o r   w h i c h   t h i s   n o d e   g r a p h   i s   o r i g i n a l l y   i n t e n d e d . 
 
 
 
 
 
 # #   S t a t u s   &   R o a d m a p 
 
 
 
 M o s t   o f   t h e   f u n c t i o n a l i t y   f o r   a   b a s i c   n o d e   g r a p h   i s   a l r e a d y   h e r e ,   w i t h   m o r e   f e a t u r e s   a n d   f i x e s   p l a n n e d . 
 
 
 
 * * R o a d m a p / T O D O * * 
 
 
 
 -   [ x ]   Z o o m / p a n   c a n v a s   ( s t i l l   b u g g y ) 
 
 -   [ x ]   B a s i c   n o d e   d r a g   n '   d r o p 
 
 -   [ x ]   B o x   s e l e c t i o n 
 
 -   [ x ]   M u l t i - s e l e c t i o n   ( s t i l l   b u g g y ) 
 
 -   [ x ]   S o c k e t s   a n d   w i r e s 
 
 -   [ x ]   P a r a m e t e r s 
 
 -   [ x ]   P a r a m e t e r   s o c k e t   i d s 
 
 -   [ x ]   P Y P I   p a c k a g e 
 
 -   [ x ]   N o d e   d e l e t e ,   d u p l i c a t e   a n d   m u t e 
 
 -   [   ]   R e f a c t o r   o u t   c o n t e x t   m e n u   s o   t h a t   i t   c a n   b e   c r e a t e d / e d i t e d   o u t s i d e   o f   t h i s   p a c k a g e 
 
 -   [ x ]   C t r l + L M B   t o   s e t   n o d e   c o n n e c t e d   t o   O u t p u t   [ # 9 8 ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o / i s s u e s / 9 8 ) 
 
 -   [ x ]   S u p p o r t   f o r   i m a g e   t h u m b n a i l s   w i t h   e x p a n d   a n d   c o l l a p s e   f u n c t i o n a l i t y   [ # 2 4 ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o / i s s u e s / 2 4 ) 
 
 -   [ x ]   S u p p o r t   f o r   d i f f e r e n t   i n p u t   d a t a t y p e s   [ # 8 3 ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o / i s s u e s / 8 3 ) 
 
 -   [   ]   A u t o   c o n n e c t   n o d e s   w h e n   d r o p p e d / d r a g g e d   o v e r   a   w i r e 
 
 -   [   ]   K e y b o a r d   s h o r t c u t s 
 
 -   [ x ]   C o n f i g u r a b l e   s e t t i n g s 
 
 -   [ x ]   L o c k   z o o m   t o   a   p r e d e f i n e d   r a n g e 
 
 -   [   ]   N o d e   g r o u p s   ( o r   " n o d e s   i n s i d e   o f   a   n o d e " )   [ # 8 1 ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o / i s s u e s / 8 1 ) 
 
 -   [   ]   S w a p   n o d e   i n p u t s   f u n c t i o n a l i t y 
 
 -   [   ]   S e t   i m a g e   a s   b a c k g r o u n d   o f   n o d e   g r a p h   ( W I P ) 
 
 
 
 * * E x t r a   p o s s i b l i t i e s   ( m a y   o r   m a y   n o t   h a p p e n . . . o r   m a y   n o t   b e   i n c l u d e d   i n   t h i s   p a c k a g e ) * * 
 
 
 
 -   [   ]   N o d e g r a p h   m i n i m a p ? 
 
 -   [   ]   S u p p o r t   f o r   m u l t i p l e   o u t p u t   n o d e s ? 
 
 -   [   ]   A u t o - a r r a n g e   n o d e s   i n   n o d e   g r a p h   ( o r g a n i z e   t h e   n o d e s ) ? 
 
 
 
 
 
 # #   C o n t r i b u t i n g 
 
 
 
 A l l   c o n t r i b u t i o n s   a r e   w e l c o m e !   S e e   [ C O N T R I B U T I N G . m d ] ( C O N T R I B U T I N G . m d )   f o r   d e t a i l s .   F e e l   f r e e   t o   o p e n   a   P R   o r   a s k   q u e s t i o n s .   : ) 
 
 
 
 
 
 # #   R e l e a s i n g   o n   P y P I 
 
 
 
 N a v i g a t e   t o   t h e   r o o t   d i r e c t o r y 
 
 
 
 R u n   ` ` p y   - m   b u i l d ` ` 
 
 
 
 T h e n   r u n   ` ` t w i n e   u p l o a d   d i s t / * ` `   a n d   f o l l o w   t h e   p r o m p t s . 
 
 
 
 
 
 # #   L i c e n s e 
 
 
 
 g s n o d e g r a p h   i s   l i c e n s e d   u n d e r   t h e   A p a c h e   2 . 0   l i c e n s e .   F e e l   f r e e   t o   u s e   t h i s   a s   a   s t a r t i n g   p o i n t ,   e t c   f o r   y o u r   o w n   p r o j e c t s . 
 
 

==> gsnodegraph-0.5.4.tar.gz: gsnodegraph-0.5.4/README.md <==
#   g s n o d e g r a p h 
 
 
 
 P o w e r f u l   c u s t o m   n o d e   g r a p h   w i d g e t   f o r   w x P y t h o n . 
 
 
 
 ! [ " g s n o d e g r a p h   d e m o " ] ( / a s s e t s / s c r e e n s h o t s / g s n o d e g r a p h - d e m o . j p g   " g s n o d e g r a p h " ) 
 
 
 
 H i g h l y   i n s p i r e d   b y   t h e   o v e r a l l   l o o k   o f   t h e   n o d e s   i n   B l e n d e r   3 D ,   i f   y o u   c o u l d n ' t   t e l l .   S o   i f   y o u ' v e   a l w a y s   w a n t e d   t o   f i n d   a   n o d e   e d i t o r   s i m i l a r   t o   B l e n d e r ' s ,   t h i s   i s   l i k e l y   y o u r   r e p o .   ; ) 
 
 
 
 I t   i s   s p e c i f i c a l l y   a i m e d   t o w a r d s   a n   i m a g e - e d i t i n g   n o d e   e d i t o r   s e t u p   a n d   i s   s e t u p   w i t h   s t y l i n g   s p e c i f i c   t o   G i m e l   S t u d i o   b y   d e f a u l t .   H o w e v e r ,   m a n y   c o l o r s   a n d   s e t t i n g s   c a n   b e   c h a n g e d   v i a   t h e   ` ` c o n s t a n t s . p y ` `   f i l e   a n d / o r   i t   c a n   b e   a d a p t e d   a n d   c h a n g e d   f o r   o t h e r   n o d e   g r a p h   u s e - c a s e s   w i t h   a   l i t t l e   k n o w l e g e   o f   w x P y t h o n . 
 
 
 
 
 
 # #   U s a g e 
 
 
 
 S i m p l y   ` ` ` p i p   i n s t a l l   g s n o d e g r a p h ` ` `   a n d   r u n   t h e   ` ` ` m a i n . p y ` ` `   f o u n d   i n   t h i s   r e p o   t o   s e e   t h e   n o d e   g r a p h   d e m o .   T h e   ` ` n o d e g r a p h . p y ` `   f i l e   s h o w s   h o w   y o u   c a n   c u s t o m i z e   a n d   o v e r r i d e   t h e   n o d e   g r a p h .   T h e   ` ` n o d e s . p y ` `   f i l e   i n   t h e   ` ` n o d e s ` `   f o l d e r   g i v e s   a   d e m o   o f   h o w   t o   s e t u p   n o d e s   t o   w o r k   w i t h   t h e   n o d e   g r a p h . 
 
 
 
 F o r   a   r e a l - l i f e   e x a m p l e   o f   t h i s   n o d e   g r a p h   i n   a c t i o n ,   s e e   [ G i m e l   S t u d i o ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o )   a   n o d e - b a s e d   2 D   i m a g e   e d i t o r   f o r   w h i c h   t h i s   n o d e   g r a p h   i s   o r i g i n a l l y   i n t e n d e d . 
 
 
 
 
 
 # #   S t a t u s   &   R o a d m a p 
 
 
 
 M o s t   o f   t h e   f u n c t i o n a l i t y   f o r   a   b a s i c   n o d e   g r a p h   i s   a l r e a d y   h e r e ,   w i t h   m o r e   f e a t u r e s   a n d   f i x e s   p l a n n e d . 
 
 
 
 * * R o a d m a p / T O D O * * 
 
 
 
 -   [ x ]   Z o o m / p a n   c a n v a s   ( s t i l l   b u g g y ) 
 
 -   [ x ]   B a s i c   n o d e   d r a g   n '   d r o p 
 
 -   [ x ]   B o x   s e l e c t i o n 
 
 -   [ x ]   M u l t i - s e l e c t i o n   ( s t i l l   b u g g y ) 
 
 -   [ x ]   S o c k e t s   a n d   w i r e s 
 
 -   [ x ]   P r o p e r t i e s - b a s e d 
 
 -   [ x ]   M u l t i - i n p u t   a n d   o u t p u t s 
 
 -   [ x ]   P Y P I   p a c k a g e 
 
 -   [ x ]   N o d e   d e l e t e ,   d u p l i c a t e   a n d   m u t e 
 
 -   [   ]   R e f a c t o r   o u t   c o n t e x t   m e n u   s o   t h a t   i t   c a n   b e   c r e a t e d / e d i t e d   o u t s i d e   o f   t h i s   p a c k a g e 
 
 -   [ x ]   C t r l + L M B   t o   s e t   n o d e   c o n n e c t e d   t o   O u t p u t   [ # 9 8 ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o / i s s u e s / 9 8 ) 
 
 -   [ x ]   S u p p o r t   f o r   i m a g e   t h u m b n a i l s   w i t h   e x p a n d   a n d   c o l l a p s e   f u n c t i o n a l i t y   [ # 2 4 ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o / i s s u e s / 2 4 ) 
 
 -   [ x ]   S u p p o r t   f o r   d i f f e r e n t   i n p u t   d a t a t y p e s   [ # 8 3 ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o / i s s u e s / 8 3 ) 
 
 -   [   ]   A u t o   c o n n e c t   n o d e s   w h e n   d r o p p e d / d r a g g e d   o v e r   a   w i r e 
 
 -   [   ]   K e y b o a r d   s h o r t c u t s 
 
 -   [ x ]   C o n f i g u r a b l e   s e t t i n g s   v i a   ` ` c o n s t a n t s . p y ` ` 
 
 -   [ x ]   L o c k   z o o m   t o   a   p r e d e f i n e d   r a n g e 
 
 -   [   ]   N o d e   g r o u p s   ( o r   " n o d e s   i n s i d e   o f   a   n o d e " )   [ # 8 1 ] ( h t t p s : / / g i t h u b . c o m / G i m e l S t u d i o / G i m e l S t u d i o / i s s u e s / 8 1 ) 
 
 -   [   ]   S w a p   n o d e   i n p u t s   f u n c t i o n a l i t y 
 
 
 
 * * E x t r a   p o s s i b l i t i e s   ( m a y   o r   m a y   n o t   h a p p e n . . . o r   m a y   n o t   b e   i n c l u d e d   i n   t h i s   p a c k a g e ) * * 
 
 
 
 -   [   ]   N o d e g r a p h   m i n i m a p ? 
 
 -   [   ]   S u p p o r t   f o r   m u l t i p l e   o u t p u t   n o d e s ? 
 
 -   [   ]   A u t o - a r r a n g e   n o d e s   i n   n o d e   g r a p h   ( o r g a n i z e   t h e   n o d e s ) ? 
 
 -   [   ]   S e t   i m a g e   a s   b a c k g r o u n d   o f   n o d e   g r a p h   ( W I P ) 
 
 
 
 
 
 # #   C o n t r i b u t i n g 
 
 
 
 * * A l l   c o n t r i b u t i o n s   a r e   w e l c o m e ! * *   F e e l   f r e e   t o   o p e n   a   P R   o r   a s k   q u e s t i o n s .   : ) 
 
 
 
 
 
 # #   R e l e a s i n g   o n   P y P I 
 
 
 
 N a v i g a t e   t o   t h e   r o o t   d i r e c t o r y 
 
 
 
 R u n   ` ` p y   - m   b u i l d ` ` 
 
 
 
 T h e n   r u n   ` ` t w i n e   u p l o a d   d i s t / * ` `   a n d   f o l l o w   t h e   p r o m p t s . 
 
 
 
 
 
 # #   L i c e n s e 
 
 
 
 g s n o d e g r a p h   i s   l i c e n s e d   u n d e r   t h e   A p a c h e   2 . 0   l i c e n s e .   F e e l   f r e e   t o   u s e   t h i s   a s   a   s t a r t i n g   p o i n t ,   e t c   f o r   y o u r   o w n   p r o j e c t s . 
 
 
